BB.Error.Hardware.NoOutputEnablePin exception (bb_servo_pca9685 v0.5.0)

Output enable pin not configured.

The PCA9685 controller was asked to enable or disable outputs, but no output enable (OE) GPIO pin was configured. Without an OE pin, the controller cannot globally enable or disable all servo outputs.

Individual actuators can still be disabled by setting their pulse width to 0.

Summary

Types

t()

@type t() :: %BB.Error.Hardware.NoOutputEnablePin{
  __exception__: true,
  bread_crumbs: term(),
  class: term(),
  controller: atom() | nil,
  path: term(),
  splode: term(),
  stacktrace: term(),
  vars: term()
}

Functions

exception(args)

@spec exception(opts :: Keyword.t()) :: %BB.Error.Hardware.NoOutputEnablePin{
  __exception__: true,
  bread_crumbs: term(),
  class: term(),
  controller: term(),
  path: term(),
  splode: term(),
  stacktrace: term(),
  vars: term()
}

Create an Elixir.BB.Error.Hardware.NoOutputEnablePin without raising it.

Keys

  • :controller